import base64
import re

EMAIL_REGEX = '([%(local)s][%(local)s.]+[%(local)s]@[%(domain)s.]+[%(domain)s])' % {
    'local': 'A-Za-z0-9!#$%&\'*+\\-/=?^_`{|}~',
    'domain': 'A-Za-z0-9\-'
}


def extract_emails(text):
    return re.findall(EMAIL_REGEX, text)


def deobfuscate_html(html):
    def unescape(html_text):
        try:
            # Python 2.6-2.7
            from HTMLParser import HTMLParser
            return HTMLParser().unescape(html_text)
        except ImportError:
            # Python 3
            import html
            try:
                return html.unescape(html_text)
            except AttributeError:
                # Python 3.2/3.3
                from html.parser import HTMLParser
                return HTMLParser().unescape(html_text)

    def replace_atob(matchobj):
        return base64.b64decode(matchobj.groups()[0].encode('utf-8')).decode('utf-8')

    html = unescape(html)
    html = re.sub('atob\\([\'"]([A-Za-z0-9+/]+)[\'"]\\)', replace_atob, html)
    return html


def scrape_emails(html):
    """
    Look for email addresses in HTML and return them. This includes addresses in text, links and even obfuscated email
    addresses. Currently supports `atob()` and HTML entities obfuscations.

    :param html: string containing HTML
    :return: a set of email addresses found in the HTML
    """
    return set(extract_emails(deobfuscate_html(html)))



import os

import sys
from setuptools import setup, find_packages

version = os.getenv('TRAVIS_TAG', '0.0')

if sys.version_info < (2, 7):
    sys.exit('Sorry, Python < 2.7 is not supported')

setup(name='email-scraper',
      version=version,
      description='Simple utility to extract email addresses from HTML, including obfuscated email addresses',
      long_description=open('README.rst').read(),
      classifiers=[
          'Development Status :: 4 - Beta',
          'Programming Language :: Python',
          'License :: OSI Approved :: MIT License',
          'Topic :: Communications :: Email',
          'Topic :: Text Processing :: Markup :: HTML'
      ],
      keywords='email scraping web obfuscate',
      author='Amir Szekely',
      author_email='kichik@gmail.com',
      url='https://github.com/kichik/email-scraper',
      license='MIT',
      packages=find_packages(exclude=['examples', 'tests']),
      include_package_data=True,
      zip_safe=True,
      tests_require=['rstcheck'],
      test_suite='tests',
      )
